Crate leap_sys

Crate leap_sys 

Re-exports

pub use self::_eLeapRS as eLeapRS;
pub use self::_eLeapTrackingMode as eLeapTrackingMode;
pub use self::_eLeapConnectionConfig as eLeapConnectionConfig;
pub use self::_eLeapAllocatorType as eLeapAllocatorType;
pub use self::_eLeapServiceDisposition as eLeapServiceDisposition;
pub use self::_eLeapConnectionStatus as eLeapConnectionStatus;
pub use self::_eLeapPolicyFlag as eLeapPolicyFlag;
pub use self::_eLeapValueType as eLeapValueType;
pub use self::_eLeapDevicePID as eLeapDevicePID;
pub use self::_eLeapDeviceStatus as eLeapDeviceStatus;
pub use self::_eLeapImageType as eLeapImageType;
pub use self::_eLeapImageFormat as eLeapImageFormat;
pub use self::_eLeapPerspectiveType as eLeapPerspectiveType;
pub use self::_eLeapCameraCalibrationType as eLeapCameraCalibrationType;
pub use self::_eLeapHandType as eLeapHandType;
pub use self::_eLeapLogSeverity as eLeapLogSeverity;
pub use self::_eLeapDroppedFrameType as eLeapDroppedFrameType;
pub use self::_eLeapIMUFlag as eLeapIMUFlag;
pub use self::_eLeapEventType as eLeapEventType;
pub use self::_eLeapRecordingFlags as eLeapRecordingFlags;
pub use self::_eLeapVersionPart as eLeapVersionPart;

Structs

LEAP_ALLOCATOR
\ingroup Structs Specifies the allocator/deallocator functions to be used when the library needs to dynamically manage memory. @since 4.0.0
_LEAP_BONE
\ingroup Structs Describes a bone’s position and orientation.
_LEAP_CALIBRATION
_LEAP_CLOCK_REBASER
_LEAP_CONFIG_CHANGE_EVENT
\ingroup Structs The result of a configuration change request. Contains a status of true for a successful change. Call LeapSaveConfigValue() to request a service config change. The change is performed asynchronously – and may fail. LeapPollConnection() returns this event structure when the request has been processed. Use the requestID value to correlate the response to the originating request. @returns The operation result code, a member of the eLeapRS enumeration. @since 3.0.0
_LEAP_CONFIG_RESPONSE_EVENT
\ingroup Structs Contains the response to a configuration value request. Call LeapRequestConfigValue() to request a service config value. The value is fetched asynchronously since it requires a service transaction. LeapPollConnection() returns this event structure when the request has been processed. Use the requestID value to correlate the response to the originating request. @since 3.0.0
_LEAP_CONNECTION
_LEAP_CONNECTION_CONFIG
\ingroup Structs Specifies the configuration for a connection. @since 3.0.0
_LEAP_CONNECTION_EVENT
\ingroup Structs Received from LeapPollConnection() when a connection to the Ultraleap Tracking Service is established. @since 3.0.0
_LEAP_CONNECTION_INFO
\ingroup Structs Information about a connection.
_LEAP_CONNECTION_LOST_EVENT
\ingroup Structs Received from LeapPollConnection() when a connection to the Ultraleap Tracking Service is lost.
_LEAP_CONNECTION_MESSAGE
\ingroup Structs Defines a basic message from the LeapC message queue. Set by calling LeapPollConnection(). @since 3.0.0
_LEAP_DEVICE
_LEAP_DEVICE_EVENT
\ingroup Structs Device event information.
_LEAP_DEVICE_FAILURE_EVENT
\ingroup Structs Device failure information. LeapPollConnection() produces a message containing this event when a device fails. Only partial information may be available. If hDevice is non-null, then you can use it to identify the failed device with a known, open device. @since 3.0.0
_LEAP_DEVICE_INFO
\ingroup Structs Properties of a Leap device. Get a LEAP_DEVICE_INFO by calling LeapGetDeviceInfo() with the handle for device. The device must be open. @since 3.0.0
_LEAP_DEVICE_REF
\ingroup Structs A reference to a Leap device.
_LEAP_DEVICE_STATUS_CHANGE_EVENT
\ingroup Structs A notification that a device’s status has changed. One of these messages is received by the client as soon as the service is connected, or when a new device is attached. @since 3.1.3
_LEAP_DIGIT
\ingroup Structs Describes the digit of a hand. Digits are members of the LEAP_HAND struct. @since 3.0.0
_LEAP_DIGIT__bindgen_ty_1__bindgen_ty_1
_LEAP_DISTORTION_MATRIX
\ingroup Structs A matrix containing lens distortion correction coordinates.
_LEAP_DISTORTION_MATRIX__bindgen_ty_1
A point in the distortion grid. @since 3.0.0
_LEAP_DROPPED_FRAME_EVENT
_LEAP_EYE_EVENT
_LEAP_FRAME_HEADER
\ingroup Structs Identifying information for a frame of tracking data. @since 3.0.0
_LEAP_HAND
\ingroup Structs Describes a tracked hand. @since 3.0.0
_LEAP_HAND__bindgen_ty_1__bindgen_ty_1
_LEAP_HEAD_POSE_EVENT
_LEAP_IMAGE
\ingroup Structs An image associated with a frame of data. @since 4.0.0
_LEAP_IMAGE_EVENT
\ingroup Structs Streaming stereo image pairs from the device.
_LEAP_IMAGE_FRAME_DESCRIPTION
\ingroup Structs Describes the image to request. Pass this struct to the LeapImageRequest() function. @since 3.0.0
_LEAP_IMAGE_PROPERTIES
\ingroup Structs Properties of a sensor image. @since 3.0.0
_LEAP_IMU_EVENT
_LEAP_LOG_EVENT
\ingroup Structs A system log message. @since 3.0.0
_LEAP_LOG_EVENTS
_LEAP_MATRIX_3x3
_LEAP_PALM
\ingroup Structs Properties associated with the palm of the hand. The Palm is a member of the LEAP_HAND struct. @since 3.0.0
_LEAP_POINT_MAPPING
_LEAP_POINT_MAPPING_CHANGE_EVENT
_LEAP_POLICY_EVENT
\ingroup Structs The response from a request to get or set a policy. LeapPollConnection() creates this struct when the response becomes available. @since 3.0.0
_LEAP_QUATERNION
\ingroup Structs A four element, floating point quaternion. @since 3.1.2
_LEAP_QUATERNION__bindgen_ty_1__bindgen_ty_1
_LEAP_RECORDING
_LEAP_RECORDING_PARAMETERS
\ingroup Structs Read/Write mode for opening a LEAP_RECORDING. since 3.2.0
_LEAP_RECORDING_STATUS
\ingroup Structs Information about a current LEAP_RECORDING. Filled in by a call to LeapRecordingGetStatus(). @since 3.2.0
_LEAP_TELEMETRY_DATA
_LEAP_TRACKING_EVENT
\ingroup Structs A snapshot, or frame of data, containing the tracking data for a single moment in time. The LEAP_FRAME struct is the container for all the tracking data. @since 3.0.0
_LEAP_TRACKING_MODE_EVENT
\ingroup Structs The response from a request to get or set a policy. LeapPollConnection() creates this struct when the response becomes available. @since 3.0.0
_LEAP_VARIANT
\ingroup Structs A variant data type used to get and set service configuration values. @since 3.0.0
_LEAP_VECTOR
\ingroup Structs A three element, floating-point vector. @since 3.0.0
_LEAP_VECTOR__bindgen_ty_1__bindgen_ty_1
_LEAP_VERSION
\ingroup Structs Version information.

Constants

LEAP_DISTORTION_MATRIX_N
_eLeapAllocatorType_eLeapAllocatorType_Double
Double-precision 64-bit floating-point @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_Float
Single-precision 32-bit floating-point @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_Int8
Signed 8-bit integer (char) @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_Int16
Signed 16-bit integer @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_Int32
Signed 32-bit integer @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_Int64
Signed 64-bit integer @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_UInt16
Unsigned 16-bit integer @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_UInt32
Unsigned 32-bit integer @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_UInt64
Unsigned 64-bit integer @since 4.0.0
_eLeapAllocatorType_eLeapAllocatorType_Uint8
Unsigned 8-bit integer (byte) @since 4.0.0
_eLeapCameraCalibrationType_eLeapCameraCalibrationType_infrared
Infrared calibration (default). @since 4.1.0
_eLeapCameraCalibrationType_eLeapCameraCalibrationType_visual
Visual calibration. @since 4.1.0
_eLeapConnectionConfig_eLeapConnectionConfig_MultiDeviceAware
The client is aware of how to handle multiple devices through the API. @since 4.1.0
_eLeapConnectionStatus_eLeapConnectionStatus_Connected
The connection is open. @since 3.0.0
_eLeapConnectionStatus_eLeapConnectionStatus_HandshakeIncomplete
Opening the connection is underway, but not complete. @since 3.0.0
_eLeapConnectionStatus_eLeapConnectionStatus_NotConnected
The connection is not open. Call LeapOpenConnection() to open a connection to the Ultraleap Tracking Service. @since 3.0.0
_eLeapConnectionStatus_eLeapConnectionStatus_NotRunning
The connection could not be opened because the Ultraleap Tracking Service does not appear to be running. @since 3.0.0
_eLeapDevicePID_eLeapDevicePID_3Di
The Ultraleap 3Di hand tracking camera. @since 5.3.0
_eLeapDevicePID_eLeapDevicePID_Dragonfly
Internal research product codename “Dragonfly”. @since 3.0.0
_eLeapDevicePID_eLeapDevicePID_Invalid
An invalid device type. Not currently in use. @since 3.1.3
_eLeapDevicePID_eLeapDevicePID_Nightcrawler
Internal research product codename “Nightcrawler”. @since 3.0.0
_eLeapDevicePID_eLeapDevicePID_Peripheral
The Leap Motion Controller (the first consumer peripheral). @since 3.0.0
_eLeapDevicePID_eLeapDevicePID_Rigel
Research product codename “Rigel”. @since 4.0.0
_eLeapDevicePID_eLeapDevicePID_SIR170
The Ultraleap Stereo IR 170 (SIR170) hand tracking module. @since 5.3.0
_eLeapDevicePID_eLeapDevicePID_Unknown
An unknown device that is compatible with the tracking software. @since 3.1.3
_eLeapDeviceStatus_eLeapDeviceStatus_BadCalibration
The device has a bad calibration record and cannot send frames. @since 3.0.0
_eLeapDeviceStatus_eLeapDeviceStatus_BadControl
The device USB control interfaces failed to initialize. @since 3.0.0
_eLeapDeviceStatus_eLeapDeviceStatus_BadFirmware
The device reports corrupt firmware or cannot install a required firmware update. @since 3.0.0
_eLeapDeviceStatus_eLeapDeviceStatus_BadTransport
The device USB connection is faulty. @since 3.0.0
_eLeapDeviceStatus_eLeapDeviceStatus_LowResource
The device has entered low-resource mode. @since 4.0.0
_eLeapDeviceStatus_eLeapDeviceStatus_Paused
Device streaming has been paused. @since 3.0.0
_eLeapDeviceStatus_eLeapDeviceStatus_Robust
There are known sources of infrared interference. Device has transitioned to robust mode in order to compensate. @since 3.1.3
_eLeapDeviceStatus_eLeapDeviceStatus_Smudged
The device’s window is smudged, tracking may be degraded. @since 3.1.3
_eLeapDeviceStatus_eLeapDeviceStatus_Streaming
The device is sending out frames. @since 3.0.0
_eLeapDeviceStatus_eLeapDeviceStatus_UnknownFailure
The device has failed, but the failure reason is not known. @since 3.0.0
_eLeapDroppedFrameType_eLeapDroppedFrameType_Other
_eLeapDroppedFrameType_eLeapDroppedFrameType_PreprocessingQueue
_eLeapDroppedFrameType_eLeapDroppedFrameType_TrackingQueue
_eLeapEventType_eLeapEventType_ConfigChange
The asynchronous response to a call to LeapSaveConfigValue(). Reports whether the change succeeded or failed. @since 3.0.0
_eLeapEventType_eLeapEventType_ConfigResponse
The asynchronous response to a call to LeapRequestConfigValue(). Contains the value of requested configuration item. @since 3.0.0
_eLeapEventType_eLeapEventType_Connection
A connection to the Ultraleap Tracking Service has been established. @since 3.0.0
_eLeapEventType_eLeapEventType_ConnectionLost
The connection to the Ultraleap Tracking Service has been lost. @since 3.0.0
_eLeapEventType_eLeapEventType_Device
A device has been detected or plugged-in. A device event is dispatched after a connection is established for any devices already plugged in. (The system currently only supports one streaming device at a time.) @since 3.0.0
_eLeapEventType_eLeapEventType_DeviceFailure
A device has failed. Device failure could be caused by hardware failure, USB controller issues, or other system instability. Note that unplugging a device generates an eLeapEventType_DeviceLost event message, not a failure message. @since 3.0.0
_eLeapEventType_eLeapEventType_DeviceLost
The device connection has been lost.
_eLeapEventType_eLeapEventType_DeviceStatusChange
Notification that a status change has been detected on an attached device
_eLeapEventType_eLeapEventType_DroppedFrame
Notification that a status change has been detected on an attached device
_eLeapEventType_eLeapEventType_Eyes
Tracked eye positions. @since 4.1.0
_eLeapEventType_eLeapEventType_HeadPose
A head pose. The message contains the timestamped head position and orientation. @since 4.1.0
_eLeapEventType_eLeapEventType_IMU
An IMU reading. @since 4.1.0
_eLeapEventType_eLeapEventType_Image
Notification that an unrequested stereo image pair is available
_eLeapEventType_eLeapEventType_ImageComplete
The request for an image is complete. The image data has been completely written to the application-provided buffer. @since 3.0.0
_eLeapEventType_eLeapEventType_ImageRequestError
The request for an image has failed. The message contains information about the failure. The client application will not receive the requested image set. @since 3.0.0
_eLeapEventType_eLeapEventType_LogEvent
A system message. @since 3.0.0
_eLeapEventType_eLeapEventType_LogEvents
An array of system messages. @since 4.0.0
_eLeapEventType_eLeapEventType_None
No event has occurred within the timeout period specified when calling LeapPollConnection(). @since 3.0.0
_eLeapEventType_eLeapEventType_PointMappingChange
Notification that point mapping has changed
_eLeapEventType_eLeapEventType_Policy
A policy change has occurred. This can be due to setting a policy with LeapSetPolicyFlags() or due to changing or policy-related config settings, including images_mode. (A user can also change these policies using the Ultraleap Tracking Control Panel.) @since 3.0.0
_eLeapEventType_eLeapEventType_Tracking
A tracking frame. The message contains the tracking data for the frame. @since 3.0.0
_eLeapEventType_eLeapEventType_TrackingMode
A tracking mode change has occurred. This can be due to changing the hmd or screentop policy with LeapSetPolicyFlags(). or setting the tracking mode using LeapSetTrackingMode(). @since 5.0.0
_eLeapHandType_eLeapHandType_Left
A left hand. @since 3.0.0
_eLeapHandType_eLeapHandType_Right
A right hand. @since 3.0.0
_eLeapIMUFlag_eLeapIMUFlag_HasAccelerometer
Has accelerometer measurements. @since 4.1.0
_eLeapIMUFlag_eLeapIMUFlag_HasGyroscope
Has gyroscope measurements. @since 4.1.0
_eLeapIMUFlag_eLeapIMUFlag_HasTemperature
Has a temperature measurement. @since 4.1.0
_eLeapImageFormat_eLeapImageFormat_IR
An infrared image. @since 3.0.0
_eLeapImageFormat_eLeapImageFormat_RGBIr_Bayer
A Bayer RGBIr image with uncorrected RGB channels. @since 3.0.0
_eLeapImageFormat_eLeapImageFormat_UNKNOWN
An invalid or unknown format. @since 3.0.0
_eLeapImageType_eLeapImageType_Default
Default, processed IR images. @since 3.0.0
_eLeapImageType_eLeapImageType_Raw
Raw images from the device. @since 3.0.0
_eLeapImageType_eLeapImageType_UNKNOWN
An invalid or unknown type. @since 3.0.0
_eLeapLogSeverity_eLeapLogSeverity_Critical
A message about a fault that could render the software or device non-functional. @since 3.0.0
_eLeapLogSeverity_eLeapLogSeverity_Information
A system status message. @since 3.0.0
_eLeapLogSeverity_eLeapLogSeverity_Unknown
The message severity is not known or was not specified. @since 3.0.0
_eLeapLogSeverity_eLeapLogSeverity_Warning
A message warning about a condition that could degrade device capabilities. @since 3.0.0
_eLeapPerspectiveType_eLeapPerspectiveType_invalid
An unknown or invalid type. @since 3.0.0
_eLeapPerspectiveType_eLeapPerspectiveType_mono
Reserved for future use. @since 3.0.0
_eLeapPerspectiveType_eLeapPerspectiveType_stereo_left
A canonically left image. @since 3.0.0
_eLeapPerspectiveType_eLeapPerspectiveType_stereo_right
A canonically right image. @since 3.0.0
_eLeapPolicyFlag_eLeapPolicyFlag_AllowPauseResume
The policy allowing an application to pause or resume service tracking. @since 3.0.0
_eLeapPolicyFlag_eLeapPolicyFlag_BackgroundFrames
The policy allowing an application to receive frames in the background. @since 3.0.0
_eLeapPolicyFlag_eLeapPolicyFlag_Images
The policy specifying whether to automatically stream images from the device. @since 4.0.0
_eLeapPolicyFlag_eLeapPolicyFlag_MapPoints
The policy allowing an application to receive per-frame map points. @since 4.0.0
_eLeapPolicyFlag_eLeapPolicyFlag_OptimizeHMD
The policy specifying whether to optimize tracking for head-mounted device. @since 3.0.0
_eLeapPolicyFlag_eLeapPolicyFlag_OptimizeScreenTop
The policy specifying whether to optimize tracking for screen-top device. @since 5.0.0
_eLeapRS_eLeapRS_BufferSizeOverflow
The specified buffer size is too large. @since 3.0.0
_eLeapRS_eLeapRS_CannotOpenDevice
The specified device could not be opened. It is possible that the device identifier is invalid, or that the device has been disconnected since being enumerated. @since 3.0.0
_eLeapRS_eLeapRS_ConcurrentPoll
LeapPollConnection is called concurrently. @since 3.1.2
_eLeapRS_eLeapRS_HandshakeIncomplete
The operation is invalid because the connection is not complete. @since 3.0.0
_eLeapRS_eLeapRS_InsufficientBuffer
The specified buffer was not large enough to complete the request. @since 3.0.0
_eLeapRS_eLeapRS_InsufficientResources
Insufficient resources existed to complete the request. @since 3.0.0
_eLeapRS_eLeapRS_InvalidArgument
An invalid argument was specified. @since 3.0.0
_eLeapRS_eLeapRS_InvalidClientID
The server incorrectly specified zero as a client ID. @since 3.0.0
_eLeapRS_eLeapRS_NotAvailable
A connection to the Ultraleap Tracking Service could not be established. @since 3.0.0
_eLeapRS_eLeapRS_NotConnected
The operation is invalid because there is no current connection. @since 3.0.0
_eLeapRS_eLeapRS_NotStreaming
The requested operation can only be performed while the device is sending data. @since 3.0.0
_eLeapRS_eLeapRS_ProtocolError
A communications protocol error occurred. @since 3.0.0
_eLeapRS_eLeapRS_RoutineIsNotSeer
The specified timestamp references a future point in time
_eLeapRS_eLeapRS_Success
The operation completed successfully.
_eLeapRS_eLeapRS_Timeout
The requested operation has timed out. @since 3.0.0
_eLeapRS_eLeapRS_TimestampTooEarly
The specified timestamp references a point too far in the past
_eLeapRS_eLeapRS_UnexpectedClosed
The connection to the service was unexpectedly closed while reading or writing a message. The server may have terminated. @since 3.0.0
_eLeapRS_eLeapRS_UnknownError
An undetermined error has occurred. This is usually the result of an abnormal operating condition in LeapC, the Ultraleap Tracking Service, or the host computer itself. @since 3.0.0
_eLeapRS_eLeapRS_UnknownImageFrameRequest
The specified request token does not appear to be valid
_eLeapRS_eLeapRS_UnknownTrackingFrameID
The specified frame ID is not valid or is no longer valid
_eLeapRS_eLeapRS_Unsupported
The request is not supported by this version of the service. @since 5.4.0
_eLeapRecordingFlags_eLeapRecordingFlags_Compressed
_eLeapRecordingFlags_eLeapRecordingFlags_Error
_eLeapRecordingFlags_eLeapRecordingFlags_Flushing
_eLeapRecordingFlags_eLeapRecordingFlags_Reading
_eLeapRecordingFlags_eLeapRecordingFlags_Writing
_eLeapServiceDisposition_eLeapServiceState_ALL
The combination of all valid flags in this enumeration
_eLeapServiceDisposition_eLeapServiceState_LowFpsDetected
The service cannot receive frames fast enough from the underlying hardware. @since 3.1.3
_eLeapServiceDisposition_eLeapServiceState_PoorPerformancePause
The service has paused itself due to an insufficient frame rate from the hardware. @since 3.1.3
_eLeapServiceDisposition_eLeapServiceState_TrackingErrorUnknown
The service has failed to start tracking due to unknown reasons. @since 5.1.16
_eLeapTrackingMode_eLeapTrackingMode_Desktop
The tracking mode optimised for desktop devices @since 5.0.0
_eLeapTrackingMode_eLeapTrackingMode_HMD
The tracking mode optimised for head-mounted devices @since 5.0.0
_eLeapTrackingMode_eLeapTrackingMode_ScreenTop
The tracking mode optimised for screen top-mounted devices @since 5.0.0
_eLeapTrackingMode_eLeapTrackingMode_Unknown
Tracking mode is not known (allows triggering of a new LEAP_TRACKING_MODE_EVENT) @since 5.0.0
_eLeapValueType_FORCE_DWORD
A string value. @since 3.0.0
_eLeapValueType_eLeapValueType_Boolean
A boolean value. @since 3.0.0
_eLeapValueType_eLeapValueType_Float
A floating point value. @since 3.0.0
_eLeapValueType_eLeapValueType_Int32
An integer value. @since 3.0.0
_eLeapValueType_eLeapValueType_String
A string value. @since 3.0.0
_eLeapValueType_eLeapValueType_Unknown
The type is unknown (which is an abnormal condition). @since 3.0.0
_eLeapVersionPart_eLeapVersionPart_ClientLibrary
The parameter for requesting the version of the client. @since 5.2.x
_eLeapVersionPart_eLeapVersionPart_ClientProtocol
The parameter for requesting the protocol version of the client. @since 5.2.x
_eLeapVersionPart_eLeapVersionPart_ServerLibrary
The parameter for requesting the version of the server. @since 5.2.x
_eLeapVersionPart_eLeapVersionPart_ServerProtocol
The parameter for requesting the protocol version of the server. @since 5.2.x
eLeapDeviceCaps_eLeapDeviceCaps_Color
The device can send color images. @since 3.0.0

Functions

LeapCameraMatrix⚠
\ingroup Functions Returns an OpenCV-compatible camera matrix. @param hConnection The connection handle created by LeapCreateConnection(). @param camera The camera to use, a member of the eLeapPerspectiveType enumeration @param[out] dest A pointer to a single-precision float array of size 9 @since 3.2.1
LeapCameraMatrixEx⚠
\ingroup Functions Returns an OpenCV-compatible camera matrix for a particular device. @param hConnection The connection handle created by LeapCreateConnection(). @param hDevice A device handle returned by LeapOpenDevice(). @param camera The camera to use, a member of the eLeapPerspectiveType enumeration @param[out] dest A pointer to a single-precision float array of size 9 @since 5.4.0
LeapCloseConnection⚠
\ingroup Functions Closes a previously opened connection.
LeapCloseDevice⚠
\ingroup Functions Closes a device handle previously opened with LeapOpenDevice.
LeapCreateClockRebaser⚠
\ingroup Functions Initializes a new Leap clock-rebaser handle object.
LeapCreateConnection⚠
\ingroup Functions Creates a new LEAP_CONNECTION object.
LeapDestroyClockRebaser⚠
\ingroup Functions Destroys a previously created clock-rebaser object.
LeapDestroyConnection⚠
\ingroup Functions Destroys a previously opened connection.
LeapDevicePIDToString⚠
\ingroup Functions Provides the human-readable canonical name of the specified device model.
LeapDistortionCoeffs⚠
\ingroup Functions Returns an OpenCV-compatible lens distortion using the 8-parameter rational model.
LeapDistortionCoeffsEx⚠
\ingroup Functions Returns an OpenCV-compatible lens distortion for a particular device, using the 8-parameter rational model.
LeapExtrinsicCameraMatrix⚠
\ingroup Functions This finds the default device and returns the result LeapExtrinsicCameraMatrixEx()
LeapExtrinsicCameraMatrixEx⚠
\ingroup Functions
LeapGetConnectionInfo⚠
\ingroup Functions Retrieves status information about the specified connection.
LeapGetDeviceInfo⚠
\ingroup Functions Gets device properties.
LeapGetDeviceList⚠
\ingroup Functions Retrieves a list of Ultraleap Tracking camera devices currently attached to the system.
LeapGetDeviceTransform⚠
\ingroup Functions Get the transform to world coordinates from 3D Leap coordinates.
LeapGetFrameSize⚠
\ingroup Functions Retrieves the number of bytes required to allocate an interpolated frame at the specified time.
LeapGetFrameSizeEx⚠
\ingroup Functions Retrieves the number of bytes required to allocate an interpolated frame at the specified time for a particular device.
LeapGetNow⚠
\ingroup Functions Samples the universal clock used by the system to timestamp image and tracking frames.
LeapGetPointMapping⚠
LeapGetPointMappingSize⚠
Not Supported:
LeapGetTrackingMode⚠
\ingroup Functions Requests the currently set tracking mode.
LeapGetTrackingModeEx⚠
\ingroup Functions Requests the currently set tracking mode for a particular device.
LeapGetVersion⚠
\ingroup Functions
LeapInterpolateEyePositions⚠
LeapInterpolateFrame⚠
\ingroup Functions Constructs a frame at the specified timestamp by interpolating between measured frames.
LeapInterpolateFrameEx⚠
\ingroup Functions Constructs a frame at the specified timestamp for a particular device by interpolating between measured frames.
LeapInterpolateFrameFromTime⚠
\ingroup Functions Constructs a frame at the specified timestamp by interpolating between a frame near the timestamp and a frame near the sourceTimestamp.
LeapInterpolateFrameFromTimeEx⚠
\ingroup Functions Constructs a frame at the specified timestamp for a particular device by interpolating between a frame near the timestamp and a frame near the sourceTimestamp.
LeapInterpolateHeadPose⚠
LeapInterpolateHeadPoseEx⚠
LeapOpenConnection⚠
\ingroup Functions Opens a connection to the service.
LeapOpenDevice⚠
\ingroup Functions Opens a device reference and retrieves a handle to the device.
LeapPixelToRectilinear⚠
\ingroup Functions Provides the corrected camera ray intercepting the specified point on the image.
LeapPixelToRectilinearEx⚠
\ingroup Functions Provides the corrected camera ray intercepting the specified point on the image for a particular device.
LeapPollConnection⚠
\ingroup Functions Polls the connection for a new event.
LeapRebaseClock⚠
\ingroup Functions Computes the Ultraleap Tracking Service clock corresponding to a specified application clock value.
LeapRecordingClose⚠
\ingroup Functions Closes a LEAP_RECORDING.
LeapRecordingGetStatus⚠
\ingroup Functions Fills in a LEAP_RECORDING_STATUS struct for an open recording. This struct provides the applicable eLeapRecordingFlags.
LeapRecordingOpen⚠
\ingroup Functions Opens or creates a LEAP_RECORDING.
LeapRecordingRead⚠
\ingroup Functions Reads a tracking frame from a LEAP_RECORDING file.
LeapRecordingReadSize⚠
\ingroup Functions Retrieves the number of bytes required to allocate the next frame in a recording.
LeapRecordingWrite⚠
\ingroup Functions Writes a tracking frame to a LEAP_RECORDING file.
LeapRectilinearToPixel⚠
\ingroup Functions Provides the point in the image corresponding to a ray projecting from the camera.
LeapRectilinearToPixelEx⚠
\ingroup Functions Provides the point in the image corresponding to a ray projecting from the camera for a particular device.
LeapRequestConfigValue⚠
\ingroup Functions Requests the current value of a service configuration setting. The value is fetched asynchronously since it requires a service transaction. LeapPollConnection() returns this event structure when the request has been processed. Use the pRequestID value to correlate the response to the originating request.
LeapSaveConfigValue⚠
\ingroup Functions Causes the client to commit a configuration change to the Ultraleap Tracking Service.
LeapScaleOffsetMatrix⚠
\ingroup Functions This finds the default device and returns the result of LeapScaleOffsetMatrixEx() @sa LeapScaleOffsetMatrixEx for additional information
LeapScaleOffsetMatrixEx⚠
\ingroup Functions
LeapSetAllocator⚠
\ingroup Functions Sets the allocator functions to use for a particular connection.
LeapSetPause⚠
\ingroup Functions Pauses the service
LeapSetPolicyFlags⚠
\ingroup Functions Sets or clears one or more policy flags.
LeapSetPolicyFlagsEx⚠
\ingroup Functions Sets or clears one or more policy flags for a particular device.
LeapSetPrimaryDevice⚠
\ingroup Functions For a multi-device aware client, sets the device to use in the context of non-“Ex” API functions which are logically device-specific but don’t provide a device parameter.
LeapSetTrackingMode⚠
\ingroup Functions Requests a tracking mode.
LeapSetTrackingModeEx⚠
\ingroup Functions Requests a tracking mode for a particular device.
LeapSubscribeEvents⚠
\ingroup Functions Subscribe to event messages based on device.
LeapTelemetryGetNow⚠
LeapTelemetryProfiling⚠
LeapUnsubscribeEvents⚠
\ingroup Functions Unsubscribe from event messages based on device.
LeapUpdateRebase⚠
\ingroup Functions Updates the relationship between the Ultraleap Tracking Service clock and the user clock.

Type Aliases

LEAP_BONE
\ingroup Structs Describes a bone’s position and orientation.
LEAP_CALIBRATION
\ingroup Structs Represents a calibration object. Not currently of any particular use. @since 3.0.0
LEAP_CLOCK_REBASER
\ingroup Structs \struct LEAP_CLOCK_REBASER An opaque clock rebase state structure. @since 3.1.2
LEAP_CONFIG_CHANGE_EVENT
\ingroup Structs The result of a configuration change request. Contains a status of true for a successful change. Call LeapSaveConfigValue() to request a service config change. The change is performed asynchronously – and may fail. LeapPollConnection() returns this event structure when the request has been processed. Use the requestID value to correlate the response to the originating request. @returns The operation result code, a member of the eLeapRS enumeration. @since 3.0.0
LEAP_CONFIG_RESPONSE_EVENT
\ingroup Structs Contains the response to a configuration value request. Call LeapRequestConfigValue() to request a service config value. The value is fetched asynchronously since it requires a service transaction. LeapPollConnection() returns this event structure when the request has been processed. Use the requestID value to correlate the response to the originating request. @since 3.0.0
LEAP_CONNECTION
\ingroup Structs \struct LEAP_CONNECTION A handle to the Leap connection object. Use this handle to specify the connection for an operation. @since 3.0.0
LEAP_CONNECTION_CONFIG
\ingroup Structs Specifies the configuration for a connection. @since 3.0.0
LEAP_CONNECTION_EVENT
\ingroup Structs Received from LeapPollConnection() when a connection to the Ultraleap Tracking Service is established. @since 3.0.0
LEAP_CONNECTION_INFO
\ingroup Structs Information about a connection.
LEAP_CONNECTION_LOST_EVENT
\ingroup Structs Received from LeapPollConnection() when a connection to the Ultraleap Tracking Service is lost.
LEAP_CONNECTION_MESSAGE
\ingroup Structs Defines a basic message from the LeapC message queue. Set by calling LeapPollConnection(). @since 3.0.0
LEAP_DEVICE
\ingroup Structs \struct LEAP_DEVICE A handle to a Leap device object. Use this handle to specify the device for an operation. @since 3.0.0
LEAP_DEVICE_EVENT
\ingroup Structs Device event information.
LEAP_DEVICE_FAILURE_EVENT
\ingroup Structs Device failure information. LeapPollConnection() produces a message containing this event when a device fails. Only partial information may be available. If hDevice is non-null, then you can use it to identify the failed device with a known, open device. @since 3.0.0
LEAP_DEVICE_INFO
\ingroup Structs Properties of a Leap device. Get a LEAP_DEVICE_INFO by calling LeapGetDeviceInfo() with the handle for device. The device must be open. @since 3.0.0
LEAP_DEVICE_REF
\ingroup Structs A reference to a Leap device.
LEAP_DEVICE_STATUS_CHANGE_EVENT
\ingroup Structs A notification that a device’s status has changed. One of these messages is received by the client as soon as the service is connected, or when a new device is attached. @since 3.1.3
LEAP_DIGIT
\ingroup Structs Describes the digit of a hand. Digits are members of the LEAP_HAND struct. @since 3.0.0
LEAP_DISTORTION_MATRIX
\ingroup Structs A matrix containing lens distortion correction coordinates.
LEAP_DROPPED_FRAME_EVENT
LEAP_EYE_EVENT
LEAP_FRAME_HEADER
\ingroup Structs Identifying information for a frame of tracking data. @since 3.0.0
LEAP_HAND
\ingroup Structs Describes a tracked hand. @since 3.0.0
LEAP_HEAD_POSE_EVENT
LEAP_IMAGE
\ingroup Structs An image associated with a frame of data. @since 4.0.0
LEAP_IMAGE_EVENT
\ingroup Structs Streaming stereo image pairs from the device.
LEAP_IMAGE_FRAME_DESCRIPTION
\ingroup Structs Describes the image to request. Pass this struct to the LeapImageRequest() function. @since 3.0.0
LEAP_IMAGE_PROPERTIES
\ingroup Structs Properties of a sensor image. @since 3.0.0
LEAP_IMU_EVENT
LEAP_LOG_EVENT
\ingroup Structs A system log message. @since 3.0.0
LEAP_LOG_EVENTS
LEAP_MATRIX_3x3
LEAP_PALM
\ingroup Structs Properties associated with the palm of the hand. The Palm is a member of the LEAP_HAND struct. @since 3.0.0
LEAP_POINT_MAPPING
LEAP_POINT_MAPPING_CHANGE_EVENT
LEAP_POLICY_EVENT
\ingroup Structs The response from a request to get or set a policy. LeapPollConnection() creates this struct when the response becomes available. @since 3.0.0
LEAP_QUATERNION
\ingroup Structs A four element, floating point quaternion. @since 3.1.2
LEAP_RECORDING
\ingroup Structs A Leap recording. @since 3.2.0
LEAP_RECORDING_PARAMETERS
\ingroup Structs Read/Write mode for opening a LEAP_RECORDING. since 3.2.0
LEAP_RECORDING_STATUS
\ingroup Structs Information about a current LEAP_RECORDING. Filled in by a call to LeapRecordingGetStatus(). @since 3.2.0
LEAP_TELEMETRY_DATA
LEAP_TRACKING_EVENT
\ingroup Structs A snapshot, or frame of data, containing the tracking data for a single moment in time. The LEAP_FRAME struct is the container for all the tracking data. @since 3.0.0
LEAP_TRACKING_MODE_EVENT
\ingroup Structs The response from a request to get or set a policy. LeapPollConnection() creates this struct when the response becomes available. @since 3.0.0
LEAP_VARIANT
\ingroup Structs A variant data type used to get and set service configuration values. @since 3.0.0
LEAP_VECTOR
\ingroup Structs A three element, floating-point vector. @since 3.0.0
LEAP_VERSION
\ingroup Structs Version information.
_eLeapAllocatorType
\ingroup Enum Defines the various types of data that may be allocated using the allocator. @since 4.0.0
_eLeapCameraCalibrationType
\ingroup Enum Camera calibration types. @since 3.0.0
_eLeapConnectionConfig
_eLeapConnectionStatus
\ingroup Enums The connection status codes. These codes can be read from the LEAP_CONNECTION_INFO struct created by a call to LeapGetConnectionInfo(). @since 3.0.0
_eLeapDevicePID
\ingroup Enum Device hardware types. @since 3.0.0
_eLeapDeviceStatus
\ingroup Enum Enumerates the device status codes. @since 3.0.0
_eLeapDroppedFrameType
_eLeapEventType
\ingroup Enum The types of event messages resulting from calling LeapPollConnection(). @since 3.0.0
_eLeapHandType
\ingroup Enum The Hand chirality types. Used in the LEAP_HAND struct. @since 3.0.0
_eLeapIMUFlag
_eLeapImageFormat
\ingroup Enum Image formats. @since 3.0.0
_eLeapImageType
\ingroup Enum Functional image types (not data formats).
_eLeapLogSeverity
\ingroup Enum System message severity types. @since 3.0.0
_eLeapPerspectiveType
\ingroup Enum Camera perspective types. @since 3.0.0
_eLeapPolicyFlag
\ingroup Enum Enumerates flags for the service policies.
_eLeapRS
\ingroup Enum Defines the codes returned by all LeapC functions. @since 3.0.0
_eLeapRecordingFlags
\ingroup Enum Defines the recording mode provided to the LeapRecordingOpen() function. Also used in members of LEAP_RECORDING_PARAMETERS and LEAP_RECORDING_STATUS. @since 3.2.0
_eLeapServiceDisposition
_eLeapTrackingMode
\ingroup Enum Enumerates values for the tracking mode.
_eLeapValueType
\ingroup Enum Identifies the operative data type of a LEAP_VARIANT struct instance. @since 3.0.0
_eLeapVersionPart
\ingroup Enum Defines the parameters used to access version information. @since 5.2.x
eLeapDeviceCaps
\ingroup Enum Flags enumerating Leap device capabilities. @since 3.0.0

Unions

_LEAP_CONNECTION_MESSAGE__bindgen_ty_1
A pointer to the event data for the current type of message. @since 3.0.0
_LEAP_DIGIT__bindgen_ty_1
_LEAP_HAND__bindgen_ty_1
The fingers of this hand. @since 3.0.0
_LEAP_QUATERNION__bindgen_ty_1
_LEAP_VARIANT__bindgen_ty_1
_LEAP_VECTOR__bindgen_ty_1
You can access the vector members as either an array or individual float values.